import pecan
from wsme import types as wtypes

from magellan.api.controllers.v1 import (
    job,
    execution,
    exclusion_list,
    scheduled_results,
)
from magellan.utils.wsme_utils import expose


class RootResource(wtypes.Base):
    """Root resource for API version 1.
    It references all other resources belonging to the API.
    """

    uri = wtypes.text


class HyphenatedController(object):
    """ Controller that support hyphens in URIs. """

    def __getattribute__(self, attr):
        if "-" in attr:
            attr = attr.replace("-", "_")
        return object.__getattribute__(self, attr)


class Controller(HyphenatedController):
    """API root controller for version 1."""

    jobs = job.JobsController()
    executions = execution.ExecutionsController()
    exclusion_lists = exclusion_list.ExclusionListController()
    scheduled_results = scheduled_results.ScheduledResultsController()

    @expose(RootResource)
    def index(self):
        return RootResource(uri='%s/%s' % (pecan.request.host_url, 'v1'))
