from oslo_log import log as logging
from wsme.rest.json import fromjson as to_model
from pecan.rest import RestController

from magellan.api.controllers.v1.resources import ScheduledResults
from magellan.db import api as db_api
from magellan.common.consts import DeviceStatus
from magellan.utils.wsme_utils import expose

LOG = logging.getLogger(__name__)


class ScheduledResultsController(RestController):
    @expose([ScheduledResults], str)
    def get_all(self, username):
        """
        Returns a list of ScheduledResults for the latest scheduled executions.
        """
        scheduled_results = []
        for execution in db_api.execution_get_all_scheduled(username):
            devices = db_api.device_get_all(execution.id)
            scheduled_results.append(to_model(ScheduledResults, {
                "unmonitored": [
                    device.address
                    for device in devices
                    if device.status == DeviceStatus.unmonitored
                ],
                **execution
            }))
        return scheduled_results
